@@ -45,15 +45,15 @@ link_files = {
             ),
             dict(
                 pattern=r'Old Setuptools #(?P<old_setuptools>\d+)',
-                url='http://bugs.python.org/setuptools/issue{old_setuptools}',
+                url='https://bugs.python.org/setuptools/issue{old_setuptools}',
             ),
             dict(
                 pattern=r'Jython #(?P<jython>\d+)',
-                url='http://bugs.jython.org/issue{jython}',
+                url='https://bugs.jython.org/issue{jython}',
             ),
             dict(
                 pattern=r'(Python #|bpo-)(?P<python>\d+)',
-                url='http://bugs.python.org/issue{python}',
+                url='https://bugs.python.org/issue{python}',
             ),
             dict(
                 pattern=r'Interop #(?P<interop>\d+)',
@@ -100,32 +100,17 @@ intersphinx_mapping = {
 # Preserve authored syntax for defaults
 autodoc_preserve_defaults = True
 
-intersphinx_mapping.update(
-    {
-        'pip': ('https://pip.pypa.io/en/latest', None),
-        'build': ('https://pypa-build.readthedocs.io/en/latest', None),
-        'PyPUG': ('https://packaging.python.org/en/latest/', None),
-        'packaging': ('https://packaging.pypa.io/en/latest/', None),
-        'twine': ('https://twine.readthedocs.io/en/stable/', None),
-        'importlib-resources': (
-            'https://importlib-resources.readthedocs.io/en/latest',
-            None,
-        ),
-    }
-)
-
-# Support tooltips on references
-extensions += ['hoverxref.extension']
-hoverxref_auto_ref = True
-hoverxref_intersphinx = [
-    'python',
-    'pip',
-    'build',
-    'PyPUG',
-    'packaging',
-    'twine',
-    'importlib-resources',
-]
+intersphinx_mapping.update({
+    'pip': ('https://pip.pypa.io/en/latest', None),
+    'build': ('https://pypa-build.readthedocs.io/en/latest', None),
+    'PyPUG': ('https://packaging.python.org/en/latest/', None),
+    'packaging': ('https://packaging.pypa.io/en/latest/', None),
+    'twine': ('https://twine.readthedocs.io/en/stable/', None),
+    'importlib-resources': (
+        'https://importlib-resources.readthedocs.io/en/latest',
+        None,
+    ),
+})
 
 # Add support for linking usernames
 github_url = 'https://github.com'
@@ -213,7 +198,12 @@ nitpick_ignore = [
 
 # Allow linking objects on other Sphinx sites seamlessly:
 intersphinx_mapping.update(
-    python=('https://docs.python.org/3', None),
+    # python=('https://docs.python.org/3', None),
+    python=('https://docs.python.org/3.11/', None),
+    # ^-- Python 3.11 is required because it still contains `distutils`.
+    #     Just leaving it as `3` would imply 3.12+, but that causes an
+    #     error with the cross references to distutils functions.
+    #     Inventory cache may cause errors, deleting it solves the problem.
 )
 
 # Add support for the unreleased "next-version" change notes
