@@ -1,3 +1,4 @@
+from functools import lru_cache
 from typing import Callable, Iterable, Iterator, TypeVar, Union, overload
 
 import setuptools.extern.jaraco.text as text
@@ -7,6 +8,12 @@ _T = TypeVar("_T")
 _StrOrIter = Union[str, Iterable[str]]
 
 
+parse_req: Callable[[str], Requirement] = lru_cache()(Requirement)
+# Setuptools parses the same requirement many times
+# (e.g. first for validation than for normalisation),
+# so it might be worth to cache.
+
+
 def parse_strings(strs: _StrOrIter) -> Iterator[str]:
     """
     Yield requirement strings for each specification in `strs`.
@@ -17,16 +24,14 @@ def parse_strings(strs: _StrOrIter) -> Iterator[str]:
 
 
 @overload
-def parse(strs: _StrOrIter) -> Iterator[Requirement]:
-    ...
+def parse(strs: _StrOrIter) -> Iterator[Requirement]: ...
 
 
 @overload
-def parse(strs: _StrOrIter, parser: Callable[[str], _T]) -> Iterator[_T]:
-    ...
+def parse(strs: _StrOrIter, parser: Callable[[str], _T]) -> Iterator[_T]: ...
 
 
-def parse(strs, parser=Requirement):
+def parse(strs, parser=parse_req):
     """
     Replacement for ``pkg_resources.parse_requirements`` that uses ``packaging``.
     """
