@@ -8,6 +8,7 @@ To read project metadata, consider using
 For simple scenarios, you can also try parsing the file directly
 with the help of ``configparser``.
 """
+
 import contextlib
 import functools
 import os
@@ -282,8 +283,8 @@ class ConfigHandler(Generic[Target]):
 
         try:
             current_value = getattr(target_obj, option_name)
-        except AttributeError:
-            raise KeyError(option_name)
+        except AttributeError as e:
+            raise KeyError(option_name) from e
 
         if current_value:
             # Already inhabited. Skipping.
@@ -556,23 +557,9 @@ class ConfigMetadataHandler(ConfigHandler["DistributionMetadata"]):
             'platforms': parse_list,
             'keywords': parse_list,
             'provides': parse_list,
-            'requires': self._deprecated_config_handler(
-                parse_list,
-                "The requires parameter is deprecated, please use "
-                "install_requires for runtime dependencies.",
-                due_date=(2023, 10, 30),
-                # Warning introduced in 27 Oct 2018
-            ),
             'obsoletes': parse_list,
             'classifiers': self._get_parser_compound(parse_file, parse_list),
             'license': exclude_files_parser('license'),
-            'license_file': self._deprecated_config_handler(
-                exclude_files_parser('license_file'),
-                "The license_file parameter is deprecated, "
-                "use license_files instead.",
-                due_date=(2023, 10, 30),
-                # Warning introduced in 23 May 2021
-            ),
             'license_files': parse_list,
             'description': parse_file,
             'long_description': parse_file,
@@ -595,11 +582,11 @@ class ConfigMetadataHandler(ConfigHandler["DistributionMetadata"]):
             # accidentally include newlines and other unintended content
             try:
                 Version(version)
-            except InvalidVersion:
+            except InvalidVersion as e:
                 raise OptionError(
                     f'Version loaded from {value} does not '
                     f'comply with PEP 440: {version}'
-                )
+                ) from e
 
             return version
 
@@ -708,9 +695,9 @@ class ConfigOptionsHandler(ConfigHandler["Distribution"]):
 
         valid_keys = ['where', 'include', 'exclude']
 
-        find_kwargs = dict(
-            [(k, v) for k, v in section_data.items() if k in valid_keys and v]
-        )
+        find_kwargs = dict([
+            (k, v) for k, v in section_data.items() if k in valid_keys and v
+        ])
 
         where = find_kwargs.get('where')
         if where is not None:
@@ -786,4 +773,4 @@ class _AmbiguousMarker(SetuptoolsDeprecationWarning):
 
 
 class _DeprecatedConfig(SetuptoolsDeprecationWarning):
-    _SEE_DOCS = "https://setuptools.pypa.io/en/latest/userguide/declarative_config.html"
+    _SEE_DOCS = "userguide/declarative_config.html"
