@@ -7,11 +7,12 @@ import itertools
 import re
 import contextlib
 import pickle
-
-from setuptools.extern import six
-from setuptools.extern.six.moves import builtins, map
+import textwrap
+import builtins
 
 import pkg_resources
+from distutils.errors import DistutilsError
+from pkg_resources import working_set
 
 if sys.platform.startswith('java'):
     import org.python.modules.posix.PosixModule as _os
@@ -22,11 +23,13 @@ try:
 except NameError:
     _file = None
 _open = open
-from distutils.errors import DistutilsError
-from pkg_resources import working_set
+
 
 __all__ = [
-    "AbstractSandbox", "DirectorySandbox", "SandboxViolation", "run_setup",
+    "AbstractSandbox",
+    "DirectorySandbox",
+    "SandboxViolation",
+    "run_setup",
 ]
 
 
@@ -37,10 +40,6 @@ def _execfile(filename, globals, locals=None):
     mode = 'rb'
     with open(filename, mode) as stream:
         script = stream.read()
-    # compile() function in Python 2.6 and 3.1 requires LF line endings.
-    if sys.version_info[:2] < (2, 7) or sys.version_info[:2] >= (3, 0) and sys.version_info[:2] < (3, 2):
-        script = script.replace(b'\r\n', b'\n')
-        script = script.replace(b'\r', b'\n')
     if locals is None:
         locals = globals
     code = compile(script, filename, 'exec')
@@ -72,8 +71,7 @@ def override_temp(replacement):
     """
     Monkey-patch tempfile.tempdir with replacement, ensuring it exists
     """
-    if not os.path.isdir(replacement):
-        os.makedirs(replacement)
+    os.makedirs(replacement, exist_ok=True)
 
     saved = tempfile.tempdir
 
@@ -99,6 +97,7 @@ class UnpickleableException(Exception):
     """
     An exception representing another Exception that could not be pickled.
     """
+
     @staticmethod
     def dump(type, exc):
         """
@@ -110,12 +109,13 @@ class UnpickleableException(Exception):
         except Exception:
             # get UnpickleableException inside the sandbox
             from setuptools.sandbox import UnpickleableException as cls
+
             return cls.dump(cls, cls(repr(exc)))
 
 
 class ExceptionSaver:
     """
-    A Context Manager that will save an exception, serialized, and restore it
+    A Context Manager that will save an exception, serialize, and restore it
     later.
     """
 
@@ -124,7 +124,7 @@ class ExceptionSaver:
 
     def __exit__(self, type, exc, tb):
         if not exc:
-            return
+            return False
 
         # dump the exception
         self._saved = UnpickleableException.dump(type, exc)
@@ -140,7 +140,7 @@ class ExceptionSaver:
             return
 
         type, exc = map(pickle.loads, self._saved)
-        six.reraise(type, exc, self._tb)
+        raise exc.with_traceback(self._tb)
 
 
 @contextlib.contextmanager
@@ -158,7 +158,8 @@ def save_modules():
     sys.modules.update(saved)
     # remove any modules imported since
     del_modules = (
-        mod_name for mod_name in sys.modules
+        mod_name
+        for mod_name in sys.modules
         if mod_name not in saved
         # exclude any encodings modules. See #285
         and not mod_name.startswith('encodings.')
@@ -187,8 +188,8 @@ def setup_context(setup_dir):
     temp_dir = os.path.join(setup_dir, 'temp')
     with save_pkg_resources_state():
         with save_modules():
-            hide_setuptools()
             with save_path():
+                hide_setuptools()
                 with save_argv():
                     with override_temp(temp_dir):
                         with pushd(setup_dir):
@@ -197,6 +198,15 @@ def setup_context(setup_dir):
                             yield
 
 
+_MODULES_TO_HIDE = {
+    'setuptools',
+    'distutils',
+    'pkg_resources',
+    'Cython',
+    '_distutils_hack',
+}
+
+
 def _needs_hiding(mod_name):
     """
     >>> _needs_hiding('setuptools')
@@ -214,8 +224,8 @@ def _needs_hiding(mod_name):
     >>> _needs_hiding('Cython')
     True
     """
-    pattern = re.compile('(setuptools|pkg_resources|distutils|Cython)(\.|$)')
-    return bool(pattern.match(mod_name))
+    base_module = mod_name.split('.', 1)[0]
+    return base_module in _MODULES_TO_HIDE
 
 
 def hide_setuptools():
@@ -225,6 +235,10 @@ def hide_setuptools():
     necessary to avoid issues such as #315 where setuptools upgrading itself
     would fail to find a function declared in the metadata.
     """
+    _distutils_hack = sys.modules.get('_distutils_hack', None)
+    if _distutils_hack is not None:
+        _distutils_hack._remove_shim()
+
     modules = filter(_needs_hiding, sys.modules)
     _clear_modules(modules)
 
@@ -234,16 +248,15 @@ def run_setup(setup_script, args):
     setup_dir = os.path.abspath(os.path.dirname(setup_script))
     with setup_context(setup_dir):
         try:
-            sys.argv[:] = [setup_script]+list(args)
+            sys.argv[:] = [setup_script] + list(args)
             sys.path.insert(0, setup_dir)
             # reset to include setup dir, w/clean callback list
             working_set.__init__()
             working_set.callbacks.append(lambda dist: dist.activate())
 
-            def runner():
+            with DirectorySandbox(setup_dir):
                 ns = dict(__file__=setup_script, __name__='__main__')
                 _execfile(setup_script, ns)
-            DirectorySandbox(setup_dir).run(runner)
         except SystemExit as v:
             if v.args and v.args[0]:
                 raise
@@ -257,29 +270,33 @@ class AbstractSandbox:
 
     def __init__(self):
         self._attrs = [
-            name for name in dir(_os)
-                if not name.startswith('_') and hasattr(self, name)
+            name
+            for name in dir(_os)
+            if not name.startswith('_') and hasattr(self, name)
         ]
 
     def _copy(self, source):
         for name in self._attrs:
             setattr(os, name, getattr(source, name))
 
+    def __enter__(self):
+        self._copy(self)
+        if _file:
+            builtins.file = self._file
+        builtins.open = self._open
+        self._active = True
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self._active = False
+        if _file:
+            builtins.file = _file
+        builtins.open = _open
+        self._copy(_os)
+
     def run(self, func):
         """Run 'func' under os sandboxing"""
-        try:
-            self._copy(self)
-            if _file:
-                builtins.file = self._file
-            builtins.open = self._open
-            self._active = True
+        with self:
             return func()
-        finally:
-            self._active = False
-            if _file:
-                builtins.file = _file
-            builtins.open = _open
-            self._copy(_os)
 
     def _mk_dual_path_wrapper(name):
         original = getattr(_os, name)
@@ -288,10 +305,12 @@ class AbstractSandbox:
             if self._active:
                 src, dst = self._remap_pair(name, src, dst, *args, **kw)
             return original(src, dst, *args, **kw)
+
         return wrap
 
     for name in ["rename", "link", "symlink"]:
-        if hasattr(_os, name): locals()[name] = _mk_dual_path_wrapper(name)
+        if hasattr(_os, name):
+            locals()[name] = _mk_dual_path_wrapper(name)
 
     def _mk_single_path_wrapper(name, original=None):
         original = original or getattr(_os, name)
@@ -300,17 +319,35 @@ class AbstractSandbox:
             if self._active:
                 path = self._remap_input(name, path, *args, **kw)
             return original(path, *args, **kw)
+
         return wrap
 
     if _file:
         _file = _mk_single_path_wrapper('file', _file)
     _open = _mk_single_path_wrapper('open', _open)
     for name in [
-        "stat", "listdir", "chdir", "open", "chmod", "chown", "mkdir",
-        "remove", "unlink", "rmdir", "utime", "lchown", "chroot", "lstat",
-        "startfile", "mkfifo", "mknod", "pathconf", "access"
+        "stat",
+        "listdir",
+        "chdir",
+        "open",
+        "chmod",
+        "chown",
+        "mkdir",
+        "remove",
+        "unlink",
+        "rmdir",
+        "utime",
+        "lchown",
+        "chroot",
+        "lstat",
+        "startfile",
+        "mkfifo",
+        "mknod",
+        "pathconf",
+        "access",
     ]:
-        if hasattr(_os, name): locals()[name] = _mk_single_path_wrapper(name)
+        if hasattr(_os, name):
+            locals()[name] = _mk_single_path_wrapper(name)
 
     def _mk_single_with_return(name):
         original = getattr(_os, name)
@@ -320,10 +357,12 @@ class AbstractSandbox:
                 path = self._remap_input(name, path, *args, **kw)
                 return self._remap_output(name, original(path, *args, **kw))
             return original(path, *args, **kw)
+
         return wrap
 
     for name in ['readlink', 'tempnam']:
-        if hasattr(_os, name): locals()[name] = _mk_single_with_return(name)
+        if hasattr(_os, name):
+            locals()[name] = _mk_single_with_return(name)
 
     def _mk_query(name):
         original = getattr(_os, name)
@@ -333,10 +372,12 @@ class AbstractSandbox:
             if self._active:
                 return self._remap_output(name, retval)
             return retval
+
         return wrap
 
     for name in ['getcwd', 'tmpnam']:
-        if hasattr(_os, name): locals()[name] = _mk_query(name)
+        if hasattr(_os, name):
+            locals()[name] = _mk_query(name)
 
     def _validate_path(self, path):
         """Called to remap or validate any path, whether input or output"""
@@ -353,53 +394,54 @@ class AbstractSandbox:
     def _remap_pair(self, operation, src, dst, *args, **kw):
         """Called for path pairs like rename, link, and symlink operations"""
         return (
-            self._remap_input(operation+'-from', src, *args, **kw),
-            self._remap_input(operation+'-to', dst, *args, **kw)
+            self._remap_input(operation + '-from', src, *args, **kw),
+            self._remap_input(operation + '-to', dst, *args, **kw),
         )
 
 
 if hasattr(os, 'devnull'):
-    _EXCEPTIONS = [os.devnull,]
+    _EXCEPTIONS = [os.devnull]
 else:
     _EXCEPTIONS = []
 
-try:
-    from win32com.client.gencache import GetGeneratePath
-    _EXCEPTIONS.append(GetGeneratePath())
-    del GetGeneratePath
-except ImportError:
-    # it appears pywin32 is not installed, so no need to exclude.
-    pass
-
 
 class DirectorySandbox(AbstractSandbox):
     """Restrict operations to a single subdirectory - pseudo-chroot"""
 
     write_ops = dict.fromkeys([
-        "open", "chmod", "chown", "mkdir", "remove", "unlink", "rmdir",
-        "utime", "lchown", "chroot", "mkfifo", "mknod", "tempnam",
+        "open",
+        "chmod",
+        "chown",
+        "mkdir",
+        "remove",
+        "unlink",
+        "rmdir",
+        "utime",
+        "lchown",
+        "chroot",
+        "mkfifo",
+        "mknod",
+        "tempnam",
     ])
 
-    _exception_patterns = [
-        # Allow lib2to3 to attempt to save a pickled grammar object (#121)
-        '.*lib2to3.*\.pickle$',
-    ]
+    _exception_patterns = []
     "exempt writing to paths that match the pattern"
 
     def __init__(self, sandbox, exceptions=_EXCEPTIONS):
         self._sandbox = os.path.normcase(os.path.realpath(sandbox))
         self._prefix = os.path.join(self._sandbox, '')
         self._exceptions = [
-            os.path.normcase(os.path.realpath(path))
-            for path in exceptions
+            os.path.normcase(os.path.realpath(path)) for path in exceptions
         ]
         AbstractSandbox.__init__(self)
 
     def _violation(self, operation, *args, **kw):
         from setuptools.sandbox import SandboxViolation
+
         raise SandboxViolation(operation, args, kw)
 
     if _file:
+
         def _file(self, path, mode='r', *args, **kw):
             if mode not in ('r', 'rt', 'rb', 'rU', 'U') and not self._ok(path):
                 self._violation("file", path, mode, *args, **kw)
@@ -428,12 +470,10 @@ class DirectorySandbox(AbstractSandbox):
 
     def _exempted(self, filepath):
         start_matches = (
-            filepath.startswith(exception)
-            for exception in self._exceptions
+            filepath.startswith(exception) for exception in self._exceptions
         )
         pattern_matches = (
-            re.match(pattern, filepath)
-            for pattern in self._exception_patterns
+            re.match(pattern, filepath) for pattern in self._exception_patterns
         )
         candidates = itertools.chain(start_matches, pattern_matches)
         return any(candidates)
@@ -456,25 +496,33 @@ class DirectorySandbox(AbstractSandbox):
             self._violation("os.open", file, flags, mode, *args, **kw)
         return _os.open(file, flags, mode, *args, **kw)
 
+
 WRITE_FLAGS = functools.reduce(
-    operator.or_, [getattr(_os, a, 0) for a in
-        "O_WRONLY O_RDWR O_APPEND O_CREAT O_TRUNC O_TEMPORARY".split()]
+    operator.or_,
+    [
+        getattr(_os, a, 0)
+        for a in "O_WRONLY O_RDWR O_APPEND O_CREAT O_TRUNC O_TEMPORARY".split()
+    ],
 )
 
 
 class SandboxViolation(DistutilsError):
     """A setup script attempted to modify the filesystem outside the sandbox"""
 
+    tmpl = textwrap.dedent(
+        """
+        SandboxViolation: {cmd}{args!r} {kwargs}
+
+        The package setup script has attempted to modify files on your system
+        that are not within the EasyInstall build area, and has been aborted.
+
+        This package cannot be safely installed by EasyInstall, and may not
+        support alternate installation locations even if you run its setup
+        script by hand.  Please inform the package's author and the EasyInstall
+        maintainers to find out if a fix or workaround is available.
+        """
+    ).lstrip()
+
     def __str__(self):
-        return """SandboxViolation: %s%r %s
-
-The package setup script has attempted to modify files on your system
-that are not within the EasyInstall build area, and has been aborted.
-
-This package cannot be safely installed by EasyInstall, and may not
-support alternate installation locations even if you run its setup
-script by hand.  Please inform the package's author and the EasyInstall
-maintainers to find out if a fix or workaround is available.""" % self.args
-
-
-#
+        cmd, args, kwargs = self.args
+        return self.tmpl.format(**locals())
