@@ -15,8 +15,7 @@ from zipfile import ZipFile
 import pytest
 from ini2toml.api import Translator
 
-# TODO: replace with `from packaging.metadata import Metadata` in future versions
-from .._packaging_compat import Metadata
+from packaging.metadata import Metadata
 
 import setuptools  # noqa ensure monkey patch to metadata
 from setuptools.dist import Distribution
