@@ -4,19 +4,20 @@ For example ``Archive`` can be used to check the contents of distribution built
 with setuptools, and ``run`` will always try to be as verbose as possible to
 facilitate debugging.
 """
+
 import os
 import subprocess
 import tarfile
 from zipfile import ZipFile
+from pathlib import Path
 
 
 def run(cmd, env=None):
     r = subprocess.run(
         cmd,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        universal_newlines=True,
-        env={**os.environ, **(env or {})}
+        capture_output=True,
+        text=True,
+        env={**os.environ, **(env or {})},
         # ^-- allow overwriting instead of discarding the current env
     )
 
@@ -32,6 +33,7 @@ def run(cmd, env=None):
 
 class Archive:
     """Compatibility layer for ZipFile/Info and TarFile/Info"""
+
     def __init__(self, filename):
         self._filename = filename
         if filename.endswith("tar.gz"):
@@ -59,3 +61,16 @@ class Archive:
                 raise ValueError(msg)
             return str(content.read(), "utf-8")
         return str(self._obj.read(zip_or_tar_info), "utf-8")
+
+
+def get_sdist_members(sdist_path):
+    with tarfile.open(sdist_path, "r:gz") as tar:
+        files = [Path(f) for f in tar.getnames()]
+    # remove root folder
+    relative_files = ("/".join(f.parts[1:]) for f in files)
+    return {f for f in relative_files if f}
+
+
+def get_wheel_members(wheel_path):
+    with ZipFile(wheel_path) as zipfile:
+        return set(zipfile.namelist())
