@@ -10,6 +10,7 @@ The number of tested packages is purposefully kept small, to minimise duration
 and the associated maintenance cost (changes in the way these packages define
 their build process may require changes in the tests).
 """
+
 import json
 import os
 import shutil
@@ -41,14 +42,16 @@ pytestmark = pytest.mark.integration
 # that `build-essential`, `gfortran` and `libopenblas-dev` are installed,
 # due to their relevance to the numerical/scientific programming ecosystem)
 EXAMPLES = [
-    ("pandas", LATEST),  # cython + custom build_ext
     ("pip", LATEST),  # just in case...
     ("pytest", LATEST),  # uses setuptools_scm
     ("mypy", LATEST),  # custom build_py + ext_modules
     # --- Popular packages: https://hugovk.github.io/top-pypi-packages/ ---
     ("botocore", LATEST),
-    ("kiwisolver", "1.3.2"),  # build_ext, version pinned due to setup_requires
+    ("kiwisolver", LATEST),  # build_ext
     ("brotli", LATEST),  # not in the list but used by urllib3
+    ("pyyaml", LATEST),  # cython + custom build_ext + custom distclass
+    ("charset-normalizer", LATEST),  # uses mypyc, used by aiohttp
+    ("protobuf", LATEST),
     # When adding packages to this list, make sure they expose a `__version__`
     # attribute, or modify the tests below
 ]
@@ -56,7 +59,20 @@ EXAMPLES = [
 
 # Some packages have "optional" dependencies that modify their build behaviour
 # and are not listed in pyproject.toml, others still use `setup_requires`
-EXTRA_BUILD_DEPS = {"sphinx": ("babel>=1.3",), "kiwisolver": ("cppy>=1.1.0",)}
+EXTRA_BUILD_DEPS = {
+    "pyyaml": ("Cython<3.0",),  # constraint to avoid errors
+    "charset-normalizer": ("mypy>=1.4.1",),  # no pyproject.toml available
+}
+
+EXTRA_ENV_VARS = {
+    "pyyaml": {"PYYAML_FORCE_CYTHON": "1"},
+    "charset-normalizer": {"CHARSET_NORMALIZER_USE_MYPYC": "1"},
+}
+
+IMPORT_NAME = {
+    "pyyaml": "yaml",
+    "protobuf": "google.protobuf",
+}
 
 
 VIRTUALENV = (sys.executable, "-m", "virtualenv")
@@ -103,9 +119,6 @@ def _prepare(tmp_path, venv_python, monkeypatch, request):
     request.addfinalizer(_debug_info)
 
 
-ALREADY_LOADED = ("pytest", "mypy")  # loaded by pytest/pytest-enabler
-
-
 @pytest.mark.parametrize('package, version', EXAMPLES)
 @pytest.mark.uses_network
 def test_install_sdist(package, version, tmp_path, venv_python, setuptools_wheel):
@@ -119,11 +132,13 @@ def test_install_sdist(package, version, tmp_path, venv_python, setuptools_wheel
 
     # Use a virtualenv to simulate PEP 517 isolation
     # but install fresh setuptools wheel to ensure the version under development
-    run([*venv_pip, "install", "-I", setuptools_wheel])
-    run([*venv_pip, "install", *INSTALL_OPTIONS, sdist])
+    env = EXTRA_ENV_VARS.get(package, {})
+    run([*venv_pip, "install", "wheel", "-I", setuptools_wheel])
+    run([*venv_pip, "install", *INSTALL_OPTIONS, sdist], env)
 
     # Execute a simple script to make sure the package was installed correctly
-    script = f"import {package}; print(getattr({package}, '__version__', 0))"
+    pkg = IMPORT_NAME.get(package, package).replace("-", "_")
+    script = f"import {pkg}; print(getattr({pkg}, '__version__', 0))"
     run([venv_python, "-c", script])
 
 
