@@ -9,8 +9,7 @@ from setuptools.dist import Distribution
 
 
 class TestBuildCLib:
-    @mock.patch(
-        'setuptools.command.build_clib.newer_pairwise_group')
+    @mock.patch('setuptools.command.build_clib.newer_pairwise_group')
     def test_build_libraries(self, mock_newer):
         dist = Distribution()
         cmd = build_clib(dist)
@@ -45,8 +44,7 @@ class TestBuildCLib:
         libs = [('example', {'sources': ['example.c'], 'obj_deps': obj_deps})]
 
         cmd.build_libraries(libs)
-        assert [['example.c', 'global.h', 'example.h']] in \
-            mock_newer.call_args[0]
+        assert [['example.c', 'global.h', 'example.h']] in mock_newer.call_args[0]
         assert not cmd.compiler.compile.called
         assert cmd.compiler.create_static_lib.call_count == 1
 
@@ -58,8 +56,7 @@ class TestBuildCLib:
         assert cmd.compiler.compile.call_count == 1
         assert cmd.compiler.create_static_lib.call_count == 1
 
-    @mock.patch(
-        'setuptools.command.build_clib.newer_pairwise_group')
+    @mock.patch('setuptools.command.build_clib.newer_pairwise_group')
     def test_build_libraries_reproducible(self, mock_newer):
         dist = Distribution()
         cmd = build_clib(dist)
