@@ -1,5 +1,4 @@
-"""wheel tests
-"""
+"""wheel tests"""
 
 from distutils.sysconfig import get_config_var
 from distutils.util import get_platform
@@ -28,44 +27,55 @@ from .textwrap import DALS
 
 WHEEL_INFO_TESTS = (
     ('invalid.whl', ValueError),
-    ('simplewheel-2.0-1-py2.py3-none-any.whl', {
-        'project_name': 'simplewheel',
-        'version': '2.0',
-        'build': '1',
-        'py_version': 'py2.py3',
-        'abi': 'none',
-        'platform': 'any',
-    }),
-    ('simple.dist-0.1-py2.py3-none-any.whl', {
-        'project_name': 'simple.dist',
-        'version': '0.1',
-        'build': None,
-        'py_version': 'py2.py3',
-        'abi': 'none',
-        'platform': 'any',
-    }),
-    ('example_pkg_a-1-py3-none-any.whl', {
-        'project_name': 'example_pkg_a',
-        'version': '1',
-        'build': None,
-        'py_version': 'py3',
-        'abi': 'none',
-        'platform': 'any',
-    }),
-    ('PyQt5-5.9-5.9.1-cp35.cp36.cp37-abi3-manylinux1_x86_64.whl', {
-        'project_name': 'PyQt5',
-        'version': '5.9',
-        'build': '5.9.1',
-        'py_version': 'cp35.cp36.cp37',
-        'abi': 'abi3',
-        'platform': 'manylinux1_x86_64',
-    }),
+    (
+        'simplewheel-2.0-1-py2.py3-none-any.whl',
+        {
+            'project_name': 'simplewheel',
+            'version': '2.0',
+            'build': '1',
+            'py_version': 'py2.py3',
+            'abi': 'none',
+            'platform': 'any',
+        },
+    ),
+    (
+        'simple.dist-0.1-py2.py3-none-any.whl',
+        {
+            'project_name': 'simple.dist',
+            'version': '0.1',
+            'build': None,
+            'py_version': 'py2.py3',
+            'abi': 'none',
+            'platform': 'any',
+        },
+    ),
+    (
+        'example_pkg_a-1-py3-none-any.whl',
+        {
+            'project_name': 'example_pkg_a',
+            'version': '1',
+            'build': None,
+            'py_version': 'py3',
+            'abi': 'none',
+            'platform': 'any',
+        },
+    ),
+    (
+        'PyQt5-5.9-5.9.1-cp35.cp36.cp37-abi3-manylinux1_x86_64.whl',
+        {
+            'project_name': 'PyQt5',
+            'version': '5.9',
+            'build': '5.9.1',
+            'py_version': 'cp35.cp36.cp37',
+            'abi': 'abi3',
+            'platform': 'manylinux1_x86_64',
+        },
+    ),
 )
 
 
 @pytest.mark.parametrize(
-    ('filename', 'info'), WHEEL_INFO_TESTS,
-    ids=[t[0] for t in WHEEL_INFO_TESTS]
+    ('filename', 'info'), WHEEL_INFO_TESTS, ids=[t[0] for t in WHEEL_INFO_TESTS]
 )
 def test_wheel_info(filename, info):
     if inspect.isclass(info):
@@ -79,21 +89,25 @@ def test_wheel_info(filename, info):
 @contextlib.contextmanager
 def build_wheel(extra_file_defs=None, **kwargs):
     file_defs = {
-        'setup.py': (DALS(
-            '''
+        'setup.py': (
+            DALS(
+                """
             # -*- coding: utf-8 -*-
             from setuptools import setup
             import setuptools
             setup(**%r)
-            '''
-        ) % kwargs).encode('utf-8'),
+            """
+            )
+            % kwargs
+        ).encode('utf-8'),
     }
     if extra_file_defs:
         file_defs.update(extra_file_defs)
     with tempdir() as source_dir:
         path.build(file_defs, source_dir)
-        subprocess.check_call((sys.executable, 'setup.py',
-                               '-q', 'bdist_wheel'), cwd=source_dir)
+        subprocess.check_call(
+            (sys.executable, 'setup.py', '-q', 'bdist_wheel'), cwd=source_dir
+        )
         yield glob.glob(os.path.join(source_dir, 'dist', '*.whl'))[0]
 
 
@@ -101,8 +115,7 @@ def tree_set(root):
     contents = set()
     for dirpath, dirnames, filenames in os.walk(root):
         for filename in filenames:
-            contents.add(os.path.join(os.path.relpath(dirpath, root),
-                                      filename))
+            contents.add(os.path.join(os.path.relpath(dirpath, root), filename))
     return contents
 
 
@@ -115,8 +128,7 @@ def flatten_tree(tree):
 
         for elem in contents:
             if isinstance(elem, dict):
-                output |= {os.path.join(node, val)
-                           for val in flatten_tree(elem)}
+                output |= {os.path.join(node, val) for val in flatten_tree(elem)}
             else:
                 output.add(os.path.join(node, elem))
     return output
@@ -127,19 +139,22 @@ def format_install_tree(tree):
         x.format(
             py_version=PY_MAJOR,
             platform=get_platform(),
-            shlib_ext=get_config_var('EXT_SUFFIX') or get_config_var('SO'))
-        for x in tree}
+            shlib_ext=get_config_var('EXT_SUFFIX') or get_config_var('SO'),
+        )
+        for x in tree
+    }
 
 
-def _check_wheel_install(filename, install_dir, install_tree_includes,
-                         project_name, version, requires_txt):
+def _check_wheel_install(
+    filename, install_dir, install_tree_includes, project_name, version, requires_txt
+):
     w = Wheel(filename)
     egg_path = os.path.join(install_dir, w.egg_name())
     w.install_as_egg(egg_path)
     if install_tree_includes is not None:
         install_tree = format_install_tree(install_tree_includes)
         exp = tree_set(install_dir)
-        assert install_tree.issubset(exp), (install_tree - exp)
+        assert install_tree.issubset(exp), install_tree - exp
 
     metadata = PathMetadata(egg_path, os.path.join(egg_path, 'EGG-INFO'))
     dist = Distribution.from_filename(egg_path, metadata=metadata)
@@ -153,7 +168,6 @@ def _check_wheel_install(filename, install_dir, install_tree_includes,
 
 
 class Record:
-
     def __init__(self, id, **kwargs):
         self._id = id
         self._fields = kwargs
@@ -163,44 +177,32 @@ class Record:
 
 
 WHEEL_INSTALL_TESTS = (
-
     dict(
         id='basic',
-        file_defs={
-            'foo': {
-                '__init__.py': ''
-            }
-        },
+        file_defs={'foo': {'__init__.py': ''}},
         setup_kwargs=dict(
             packages=['foo'],
         ),
         install_tree=flatten_tree({
             'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt'
-                ],
-                'foo': ['__init__.py']
+                'EGG-INFO': ['PKG-INFO', 'RECORD', 'WHEEL', 'top_level.txt'],
+                'foo': ['__init__.py'],
             }
         }),
     ),
-
     dict(
         id='utf-8',
         setup_kwargs=dict(
             description='Description accentuée',
-        )
+        ),
     ),
-
     dict(
         id='data',
         file_defs={
             'data.txt': DALS(
-                '''
+                """
                 Some data...
-                '''
+                """
             ),
         },
         setup_kwargs=dict(
@@ -208,24 +210,16 @@ WHEEL_INSTALL_TESTS = (
         ),
         install_tree=flatten_tree({
             'foo-1.0-py{py_version}.egg': {
-                'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt'
-                ],
-                'data_dir': [
-                    'data.txt'
-                ]
+                'EGG-INFO': ['PKG-INFO', 'RECORD', 'WHEEL', 'top_level.txt'],
+                'data_dir': ['data.txt'],
             }
         }),
     ),
-
     dict(
         id='extension',
         file_defs={
             'extension.c': DALS(
-                '''
+                """
                 #include "Python.h"
 
                 #if PY_MAJOR_VERSION >= 3
@@ -265,35 +259,36 @@ WHEEL_INSTALL_TESTS = (
                     return module;
                 #endif
                 }
-                '''
+                """
             ),
         },
         setup_kwargs=dict(
             ext_modules=[
-                Record('setuptools.Extension',
-                       name='extension',
-                       sources=['extension.c'])
+                Record(
+                    'setuptools.Extension', name='extension', sources=['extension.c']
+                )
             ],
         ),
         install_tree=flatten_tree({
             'foo-1.0-py{py_version}-{platform}.egg': [
                 'extension{shlib_ext}',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                ]},
+                {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'top_level.txt',
+                    ]
+                },
             ]
         }),
     ),
-
     dict(
         id='header',
         file_defs={
             'header.h': DALS(
-                '''
-                '''
+                """
+                """
             ),
         },
         setup_kwargs=dict(
@@ -302,30 +297,31 @@ WHEEL_INSTALL_TESTS = (
         install_tree=flatten_tree({
             'foo-1.0-py{py_version}.egg': [
                 'header.h',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'top_level.txt',
-                ]},
+                {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'top_level.txt',
+                    ]
+                },
             ]
         }),
     ),
-
     dict(
         id='script',
         file_defs={
             'script.py': DALS(
-                '''
+                """
                 #/usr/bin/python
                 print('hello world!')
-                '''
+                """
             ),
             'script.sh': DALS(
-                '''
+                """
                 #/bin/sh
                 echo 'hello world!'
-                '''
+                """
             ),
         },
         setup_kwargs=dict(
@@ -338,16 +334,11 @@ WHEEL_INSTALL_TESTS = (
                     'RECORD',
                     'WHEEL',
                     'top_level.txt',
-                    {'scripts': [
-                        'script.py',
-                        'script.sh'
-                    ]}
-
+                    {'scripts': ['script.py', 'script.sh']},
                 ]
             }
-        })
+        }),
     ),
-
     dict(
         id='requires1',
         install_requires='foobar==2.0',
@@ -363,81 +354,78 @@ WHEEL_INSTALL_TESTS = (
             }
         }),
         requires_txt=DALS(
-            '''
+            """
             foobar==2.0
-            '''
+            """
         ),
     ),
-
     dict(
         id='requires2',
-        install_requires='''
+        install_requires="""
         bar
         foo<=2.0; %r in sys_platform
-        ''' % sys.platform,
+        """
+        % sys.platform,
         requires_txt=DALS(
-            '''
+            """
             bar
             foo<=2.0
-            '''
+            """
         ),
     ),
-
     dict(
         id='requires3',
-        install_requires='''
+        install_requires="""
         bar; %r != sys_platform
-        ''' % sys.platform,
+        """
+        % sys.platform,
     ),
-
     dict(
         id='requires4',
-        install_requires='''
+        install_requires="""
         foo
-        ''',
+        """,
         extras_require={
             'extra': 'foobar>3',
         },
         requires_txt=DALS(
-            '''
+            """
             foo
 
             [extra]
             foobar>3
-            '''
+            """
         ),
     ),
-
     dict(
         id='requires5',
         extras_require={
             'extra': 'foobar; %r != sys_platform' % sys.platform,
         },
         requires_txt=DALS(
-            '''
+            """
             [extra]
-            '''
+            """
         ),
     ),
-
     dict(
         id='requires_ensure_order',
-        install_requires='''
+        install_requires="""
         foo
         bar
         baz
         qux
-        ''',
+        """,
         extras_require={
-            'extra': '''
+            'extra': """
             foobar>3
             barbaz>4
             bazqux>5
             quxzap>6
-            ''',
+            """,
         },
         requires_txt=DALS(
-            '''
+            """
             foo
             bar
             baz
@@ -448,17 +436,14 @@ WHEEL_INSTALL_TESTS = (
             barbaz>4
             bazqux>5
             quxzap>6
-            '''
+            """
         ),
     ),
-
     dict(
         id='namespace_package',
         file_defs={
             'foo': {
-                'bar': {
-                    '__init__.py': ''
-                },
+                'bar': {'__init__.py': ''},
             },
         },
         setup_kwargs=dict(
@@ -468,27 +453,31 @@ WHEEL_INSTALL_TESTS = (
         install_tree=flatten_tree({
             'foo-1.0-py{py_version}.egg': [
                 'foo-1.0-py{py_version}-nspkg.pth',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'namespace_packages.txt',
-                    'top_level.txt',
-                ]},
-                {'foo': [
-                    '__init__.py',
-                    {'bar': ['__init__.py']},
-                ]},
+                {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'namespace_packages.txt',
+                        'top_level.txt',
+                    ]
+                },
+                {
+                    'foo': [
+                        '__init__.py',
+                        {'bar': ['__init__.py']},
+                    ]
+                },
             ]
         }),
     ),
-
     dict(
         id='empty_namespace_package',
         file_defs={
             'foobar': {
-                '__init__.py':
-                    "__import__('pkg_resources').declare_namespace(__name__)",
+                '__init__.py': (
+                    "__import__('pkg_resources').declare_namespace(__name__)"
+                )
             },
         },
         setup_kwargs=dict(
@@ -498,20 +487,23 @@ WHEEL_INSTALL_TESTS = (
         install_tree=flatten_tree({
             'foo-1.0-py{py_version}.egg': [
                 'foo-1.0-py{py_version}-nspkg.pth',
-                {'EGG-INFO': [
-                    'PKG-INFO',
-                    'RECORD',
-                    'WHEEL',
-                    'namespace_packages.txt',
-                    'top_level.txt',
-                ]},
-                {'foobar': [
-                    '__init__.py',
-                ]},
+                {
+                    'EGG-INFO': [
+                        'PKG-INFO',
+                        'RECORD',
+                        'WHEEL',
+                        'namespace_packages.txt',
+                        'top_level.txt',
+                    ]
+                },
+                {
+                    'foobar': [
+                        '__init__.py',
+                    ]
+                },
             ]
         }),
     ),
-
     dict(
         id='data_in_package',
         file_defs={
@@ -519,11 +511,11 @@ WHEEL_INSTALL_TESTS = (
                 '__init__.py': '',
                 'data_dir': {
                     'data.txt': DALS(
-                        '''
+                        """
                         Some data...
-                        '''
+                        """
                     ),
-                }
+                },
             }
         },
         setup_kwargs=dict(
@@ -540,19 +532,21 @@ WHEEL_INSTALL_TESTS = (
                 ],
                 'foo': [
                     '__init__.py',
-                    {'data_dir': [
-                        'data.txt',
-                    ]}
-                ]
+                    {
+                        'data_dir': [
+                            'data.txt',
+                        ]
+                    },
+                ],
             }
         }),
     ),
-
 )
 
 
 @pytest.mark.parametrize(
-    'params', WHEEL_INSTALL_TESTS,
+    'params',
+    WHEEL_INSTALL_TESTS,
     ids=list(params['id'] for params in WHEEL_INSTALL_TESTS),
 )
 def test_wheel_install(params):
@@ -570,26 +564,30 @@ def test_wheel_install(params):
         install_requires=install_requires,
         extras_require=extras_require,
         extra_file_defs=file_defs,
-        **setup_kwargs
+        **setup_kwargs,
     ) as filename, tempdir() as install_dir:
-        _check_wheel_install(filename, install_dir,
-                             install_tree, project_name,
-                             version, requires_txt)
+        _check_wheel_install(
+            filename, install_dir, install_tree, project_name, version, requires_txt
+        )
 
 
 def test_wheel_install_pep_503():
-    project_name = 'Foo_Bar'    # PEP 503 canonicalized name is "foo-bar"
+    project_name = 'Foo_Bar'  # PEP 503 canonicalized name is "foo-bar"
     version = '1.0'
     with build_wheel(
         name=project_name,
         version=version,
     ) as filename, tempdir() as install_dir:
-        new_filename = filename.replace(project_name,
-                                        canonicalize_name(project_name))
+        new_filename = filename.replace(project_name, canonicalize_name(project_name))
         shutil.move(filename, new_filename)
-        _check_wheel_install(new_filename, install_dir, None,
-                             canonicalize_name(project_name),
-                             version, None)
+        _check_wheel_install(
+            new_filename,
+            install_dir,
+            None,
+            canonicalize_name(project_name),
+            version,
+            None,
+        )
 
 
 def test_wheel_no_dist_dir():
@@ -602,32 +600,37 @@ def test_wheel_no_dist_dir():
         zipfile.ZipFile(wheel_path, 'w').close()
         with tempdir() as install_dir:
             with pytest.raises(ValueError):
-                _check_wheel_install(wheel_path, install_dir, None,
-                                     project_name,
-                                     version, None)
+                _check_wheel_install(
+                    wheel_path, install_dir, None, project_name, version, None
+                )
 
 
 def test_wheel_is_compatible(monkeypatch):
     def sys_tags():
-        for t in parse_tag('cp36-cp36m-manylinux1_x86_64'):
-            yield t
-    monkeypatch.setattr('setuptools.wheel.sys_tags', sys_tags)
-    assert Wheel(
-        'onnxruntime-0.1.2-cp36-cp36m-manylinux1_x86_64.whl').is_compatible()
+        return {
+            (t.interpreter, t.abi, t.platform)
+            for t in parse_tag('cp36-cp36m-manylinux1_x86_64')
+        }
+
+    monkeypatch.setattr('setuptools.wheel._get_supported_tags', sys_tags)
+    assert Wheel('onnxruntime-0.1.2-cp36-cp36m-manylinux1_x86_64.whl').is_compatible()
 
 
 def test_wheel_mode():
     @contextlib.contextmanager
     def build_wheel(extra_file_defs=None, **kwargs):
         file_defs = {
-            'setup.py': (DALS(
-                '''
+            'setup.py': (
+                DALS(
+                    """
                 # -*- coding: utf-8 -*-
                 from setuptools import setup
                 import setuptools
                 setup(**%r)
-                '''
-            ) % kwargs).encode('utf-8'),
+                """
+                )
+                % kwargs
+            ).encode('utf-8'),
         }
         if extra_file_defs:
             file_defs.update(extra_file_defs)
@@ -635,24 +638,25 @@ def test_wheel_mode():
             path.build(file_defs, source_dir)
             runsh = pathlib.Path(source_dir) / "script.sh"
             os.chmod(runsh, 0o777)
-            subprocess.check_call((sys.executable, 'setup.py',
-                                   '-q', 'bdist_wheel'), cwd=source_dir)
+            subprocess.check_call(
+                (sys.executable, 'setup.py', '-q', 'bdist_wheel'), cwd=source_dir
+            )
             yield glob.glob(os.path.join(source_dir, 'dist', '*.whl'))[0]
 
     params = dict(
         id='script',
         file_defs={
             'script.py': DALS(
-                '''
+                """
                 #/usr/bin/python
                 print('hello world!')
-                '''
+                """
             ),
             'script.sh': DALS(
-                '''
+                """
                 #/bin/sh
                 echo 'hello world!'
-                '''
+                """
             ),
         },
         setup_kwargs=dict(
@@ -665,14 +669,10 @@ def test_wheel_mode():
                     'RECORD',
                     'WHEEL',
                     'top_level.txt',
-                    {'scripts': [
-                        'script.py',
-                        'script.sh'
-                    ]}
-
+                    {'scripts': ['script.py', 'script.sh']},
                 ]
             }
-        })
+        }),
     )
 
     project_name = params.get('name', 'foo')
@@ -687,11 +687,11 @@ def test_wheel_mode():
         install_requires=[],
         extras_require={},
         extra_file_defs=file_defs,
-        **setup_kwargs
+        **setup_kwargs,
     ) as filename, tempdir() as install_dir:
-        _check_wheel_install(filename, install_dir,
-                             install_tree, project_name,
-                             version, None)
+        _check_wheel_install(
+            filename, install_dir, install_tree, project_name, version, None
+        )
         w = Wheel(filename)
         base = pathlib.Path(install_dir) / w.egg_name()
         script_sh = base / "EGG-INFO" / "scripts" / "script.sh"
